<?php
namespace Planejamento\Repositories;

use Setforms2\Shared\Registry;

class Receserv extends \Doctrine\ORM\EntityRepository
{

    public static function verificaProdInativoFilial($nrorg, $filial, $prato, $filAux, $maxNivelProd, $servico)
    {
        $query = "SELECT P.NMPRODUTO, P.CDARVPROD, P.IDPRODATIVPR, NVL(PF.IDPRODATIV, 'A') AS IDPRODATIV
                  FROM   (PRODUTO P LEFT JOIN PRODFILI PF
                    ON PF.CDPRODUTO = P.CDPRODUTO   AND
                       PF.CDFILIAL  = :P_CDFILIAL   AND
                       P.NRORG      = PF.NRORG), RECESERV RS
                  WHERE
                     P.CDNVPRODUTO   = :P_CDNVPRODUTO  AND
                     RS.CDFILIAL     = :P_CDFILIAL     AND
                     RS.CDSERVFILI   = :P_CDSERVFILI   AND
                     RS.CDPRATO      = :P_CDPRATO      AND
                     RS.CDFILAUXPRAT = :P_CDFILAUXPRAT AND
                     P.CDPRODUTO     = RS.CDPRODUTO    AND
                     RS.NRORG        = P.NRORG";

        $param = array(
            "P_CDNVPRODUTO" => $maxNivelProd,
            "P_CDFILIAL" => $filial,
            "P_CDPRATO" => $prato,
            "P_CDFILAUXPRAT" => $filAux,
            "P_NRORG" => $nrorg,
            "P_CDSERVFILI" => $servico
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $result = $conn->fetchAll($query, $param);
            return $result;
        } catch (\Exception $e) {
            throw $e;
        }

    }

    public static function atualizaProdFatorCorrecaoLiquidaServico($produto, $quantidade, $prato, $nrorg, $filAux, $quanValorNutri, $vrpefatcorse)
    {

        $query = "UPDATE RECESERV
                  SET  VRPEFATCORSE = :VRPEFATCORS,
                       QTPRODRECSER = :QTPRODRECSER,
                       QTCALCNUTRSE = :QTCALCNUTRSE
                  WHERE CDFILAUXPRAT = :OLD_CDFILAUXPRAT
                        AND CDPRATO = :OLD_CDPRATO
                        AND CDPRODUTO = :OLD_CDPRODUTO
                        AND NRORG = :OLD_NRORG";

        $param = array(
            "VRPEFATCORS" => $vrpefatcorse,
            "QTCALCNUTRSE" => $quanValorNutri,
            "OLD_CDPRODUTO" => $produto,
            "QTPRODRECSER" => $quantidade,
            "OLD_CDPRATO" => $prato,
            "OLD_CDFILAUXPRAT" => $filAux,
            "OLD_NRORG" => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function atualizaProdFatorCorrecaoBrutaServico($produto, $quantidade, $prato, $nrorg, $filAux, $quanValorNutri, $vrpefatcorse)
    {

        $query = "UPDATE RECESERV
                  SET  VRPEFATCORSE = :VRPEFATCORSE,
                       QTBRUTASEUNR = :QTBRUTASEUNR,
                       QTCALCNUTRSE = :QTCALCNUTRSE
                  WHERE CDFILAUXPRAT = :OLD_CDFILAUXPRAT
                        AND CDPRATO = :OLD_CDPRATO
                        AND CDPRODUTO = :OLD_CDPRODUTO
                        AND NRORG = :OLD_NRORG";

        $param = array(
            "VRPEFATCORSE" => $vrpefatcorse,
            "QTCALCNUTRSE" => $quanValorNutri,
            "OLD_CDPRODUTO" => $produto,
            "QTBRUTASEUNR" => $quantidade,
            "OLD_CDPRATO" => $prato,
            "OLD_CDFILAUXPRAT" => $filAux,
            "OLD_NRORG" => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public static function deletaReceita($cdprato, $cdfilauxprat,$cdfilidest, $cdservdest, $nrorg ) {

        $query = "DELETE FROM RECESERV
                   WHERE
                      CDPRATO      = :CDPRATDEST   AND
                      CDFILAUXPRAT = :CDFILAUXDEST AND
                      CDFILIAL     = :CDFILIDEST   AND
                      CDSERVFILI   = :CDSERVDEST
                      NRORG        = :NRORG";

        $param = array(
            "CDPRATDEST" => $cdprato,
            "CDFILAUXDEST" => $cdfilauxprat,
            "CDFILIDEST" => $cdfilidest,
            ":CDSERVDEST" => $cdservdest,
            "NRORG" => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }

    }

    public static function sobrepoeReceitaServico($cdfilidest, $proporcao, $cdprato, $cdfilauxprat, $receitaorig,
                                                  $cdfilcentpme = null, $cdtipocard = null, $cdfiliorig, $cdservorig, $nrorg, $cdservdest) {
        $query = "INSERT INTO RECESERV
                  ( CDPRATO,
                    CDFILAUXPRAT,
                    CDFILIAL,
                    CDSERVFILI,
                    CDPRODUTO,
                    QTPRODRECSER,
                    SGUNIDADE,
                    VRPEFATCORSE,
                    VRPEFATCOCSE,
                    HRTEMPPREPSE,
                    QTUNIDESTSE,
                    QTBRUTASE,
                    CDAPRERECE,
                    QTBRUTASEUNR,
                    VRPEFATNUTSE,
                    QTCALCNUTRSE,
                    IDQTDEFIXSE )

                  (SELECT  CDPRATO, CDFILAUXPRAT, :CDFILIDEST   AS CDFILIAL, :CDSERVDEST   AS CDSERVFILI, CDPRODUTO,
                    (QTPRODPRAT * :PROPORCAO)  AS QTPRODUTO, SGUNIDADE, VRPEFATCORPR AS VRPEFATCOR, VRPEFATCOCPR AS VRPEFATCOC,
                    HRTEMPPREPPR AS HRTEMPPREP, (QTUNIDESTPR * :PROPORCAO)  AS QTDERECE, (QTBRUTAPR * :PROPORCAO)   AS QTBRUTA, CDAPRERECE,
                    (QTBRUTAPRUNR * :PROPORCAO) AS QTBRUTAUNR, VRPEFATNUTPR  AS VRPEFATNUT, (QTCALCNUTRPR * :PROPORCAO) AS QTCALCNUTR, IDQTDEFIXPR

                  FROM
                    RECEPADR
                  WHERE
                    (CDPRATO       = :CDPRATORIG)   AND
                    (CDFILAUXPRAT  = :CDFILAUXORIG) AND
                    (:IDTIPORECE = 'P')

                  UNION ALL

                  SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, :CDSERVDEST AS CDSERVFILI, CDPRODUTO,
                    (QTPRODPRATTP * :PROPORCAO) AS QTPRODUTO, SGUNIDADE, VRPEFATCORPRTP AS VRPEFATCOR, VRPEFATCOCPRTP AS VRPEFATCOC,
                    HRTEMPPREPPRTP AS HRTEMPPREP, (QTUNIDESTPRTP * :PROPORCAO) AS QTDERECE, (QTBRUTAPRTP * :PROPORCAO) AS QTBRUTA, CDAPRERECE,
                    (QTBRUTAPRUNRTP * :PROPORCAO) AS QTBRUTAUNR, VRPEFATNUTPRTP AS VRPEFATNUT, (QTCALCNUTRPRTP * :PROPORCAO) AS QTCALCNUTR, IDQTDEFIXPRTP
                  FROM
                    RECETPCARD
                  WHERE
                    (CDPRATO       = :CDPRATORIG)   AND
                    (CDFILAUXPRAT  = :CDFILAUXORIG) AND
                    (CDFILCENTPME  = :CDFILCENTPME) AND
                    (CDTIPOCARD    = :CDTIPOCARD)   AND
                    (:IDTIPORECE   = 'T')

                  UNION ALL

                  SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, :CDSERVDEST AS CDSERVFILI, CDPRODUTO,
                    (QTPRODRECLOC * :PROPORCAO) AS QTPRODUTO, SGUNIDADE, VRPEFATCORLO AS VRPEFATCOR, VRPEFATCOCLO AS VRPEFATCOC,
                    HRTEMPPREPLO AS HRTEMPPREP, (QTUNIDESTLO * :PROPORCAO) AS QTDERECE, (QTBRUTALO * :PROPORCAO)   AS QTBRUTA, CDAPRERECE,
                    (QTBRUTALOUNR * :PROPORCAO)  AS    QTBRUTAUNR, VRPEFATNUTLO   AS  VRPEFATNUT, (QTCALCNUTRLO * :PROPORCAO) AS   QTCALCNUTR, IDQTDEFIXLO
                  FROM
                    RECEFILI
                  WHERE
                    (CDPRATO       = :CDPRATORIG)   AND
                    (CDFILAUXPRAT  = :CDFILAUXORIG) AND
                    (CDFILIAL      = :CDFILIORIG)   AND
                    (:IDTIPORECE   = 'F')

                  UNION ALL

                  SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, :CDSERVDEST  AS CDSERVFILI, CDPRODUTO,
                    (QTPRODRECSER * :PROPORCAO) AS QTPRODUTO, SGUNIDADE, VRPEFATCORSE AS VRPEFATCOR, VRPEFATCOCSE AS VRPEFATCOC,
                    HRTEMPPREPSE AS HRTEMPPREP, (QTUNIDESTSE * :PROPORCAO)  AS QTDERECE, (QTBRUTASE * :PROPORCAO)   AS QTBRUTA, CDAPRERECE,
                    (QTBRUTASEUNR * :PROPORCAO)  AS    QTBRUTAUNR, VRPEFATNUTSE   AS  VRPEFATNUT, (QTCALCNUTRSE * :PROPORCAO) AS   QTCALCNUTR, IDQTDEFIXSE
                  FROM
                    RECESERV
                  WHERE
                    (CDPRATO       = :CDPRATORIG)   AND
                    (CDFILAUXPRAT  = :CDFILAUXORIG) AND
                    (CDFILIAL      = :CDFILIORIG)   AND
                    (CDSERVFILI    = :CDSERVORIG)   AND
                    (:IDTIPORECE   = 'S'))";

        $param = array(
            "CDFILIDEST"   => $cdfilidest,
            "PROPORCAO"    => $proporcao,
            "CDPRATORIG"   => $cdprato,
            "CDFILAUXORIG" => $cdfilauxprat,
            "IDTIPORECE"   => $receitaorig,
            "CDFILCENTPME" => $cdfilcentpme,
            "CDTIPOCARD"   => $cdtipocard,
            "CDFILIORIG"   => $cdfiliorig,
            "CDSERVORIG"   => $cdservorig,
            "CDSERVDEST"   => $cdservdest,
            "NRORG"        => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }

    }
	
	public static function acrescentaReceitaServico($cdfilidest, $proporcao, $cdprato, $cdfilauxprat, $receitaorig,
                                                  $cdfilcentpme = null, $cdtipocard = null, $cdfiliorig, $cdservorig, $nrorg, $cdservdest)
    {
        $query = "INSERT INTO RECESERV
                  ( CDPRATO,
                    CDFILAUXPRAT,
                    CDFILIAL,
                    CDSERVFILI,
                    CDPRODUTO,
                    QTPRODRECSER,
                    SGUNIDADE,
                    VRPEFATCORSE,
                    VRPEFATCOCSE,
                    HRTEMPPREPSE,
                    QTUNIDESTSE,
                    QTBRUTASE,
                    CDAPRERECE,
                    QTBRUTASEUNR,
                    VRPEFATNUTSE,
                    QTCALCNUTRSE,
                    IDQTDEFIXSE )

                  ( SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, :CDSERVDEST AS CDSERVFILI, CDPRODUTO, (QTPRODPRAT * :PROPORCAO) AS QTPRODUTO,
                      SGUNIDADE, VRPEFATCORPR AS VRPEFATCOR, VRPEFATCOCPR AS VRPEFATCOC, HRTEMPPREPPR AS HRTEMPPREP, (QTUNIDESTPR * :PROPORCAO) AS QTDERECE,
                      (QTBRUTAPR * :PROPORCAO) AS QTBRUTA, CDAPRERECE, (QTBRUTAPRUNR * :PROPORCAO)  AS QTBRUTAUNR, VRPEFATNUTPR AS VRPEFATNUT,
                      (QTCALCNUTRPR * :PROPORCAO) AS QTCALCNUTR, IDQTDEFIXPR
                    FROM
                      RECEPADR
                    WHERE
                      (CDPRATO       = :CDPRATO)  AND
                      (CDFILAUXPRAT  = :CDFILAUX) AND
                      (:IDTIPORECE   = 'P')       AND
                      (CDPRODUTO NOT IN ( SELECT CDPRODUTO
                                          FROM RECESERV
                                          WHERE
                                          CDPRATO      = :CDPRATO    AND
                                          CDFILAUXPRAT = :CDFILAUX   AND
                                          CDFILIAL     = :CDFILIDEST AND
                                          CDSERVFILI   = :CDSERVDEST ))

                  UNION ALL

                    SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST AS CDFILIAL, :CDSERVDEST AS CDSERVFILI, CDPRODUTO, (QTPRODRECLOC * :PROPORCAO) AS QTPRODUTO,
                      SGUNIDADE,VRPEFATCORLO AS VRPEFATCOR, VRPEFATCOCLO AS VRPEFATCOC, HRTEMPPREPLO AS HRTEMPPREP, (QTUNIDESTLO * :PROPORCAO) AS QTDERECE,
                      (QTBRUTALO * :PROPORCAO) AS QTBRUTA, CDAPRERECE, (QTBRUTALOUNR * :PROPORCAO) AS QTBRUTAUNR, VRPEFATNUTLO   AS  VRPEFATNUT,
                      (QTCALCNUTRLO * :PROPORCAO) AS   QTCALCNUTR, IDQTDEFIXLO
                    FROM
                      RECEFILI
                    WHERE
                      (CDPRATO       = :CDPRATO)    AND
                      (CDFILAUXPRAT  = :CDFILAUX)   AND
                      (CDFILIAL      = :CDFILIORIG) AND
                      (:IDTIPORECE   = 'L')           AND
                      (CDPRODUTO NOT IN ( SELECT CDPRODUTO
                                          FROM RECESERV
                                          WHERE
                                            CDPRATO      = :CDPRATO  AND
                                            CDFILAUXPRAT = :CDFILAUX AND
                                            CDFILIAL     = :CDFILIDEST AND
                                            CDSERVFILI   = :CDSERVDEST ))

                    UNION ALL

                    SELECT CDPRATO, CDFILAUXPRAT, :CDFILIDEST   AS CDFILIAL, :CDSERVDEST AS CDSERVFILI, CDPRODUTO, (QTPRODRECSER * :PROPORCAO) AS QTPRODUTO,
                      SGUNIDADE, VRPEFATCORSE AS VRPEFATCOR, VRPEFATCOCSE AS VRPEFATCOC, HRTEMPPREPSE AS HRTEMPPREP, (QTUNIDESTSE * :PROPORCAO) AS QTDERECE,
                      (QTBRUTASE * :PROPORCAO) AS QTBRUTA, CDAPRERECE, (QTBRUTASEUNR * :PROPORCAO) AS QTBRUTAUNR, VRPEFATNUTSE   AS  VRPEFATNUT,
                      (QTCALCNUTRSE * :PROPORCAO) AS   QTCALCNUTR, IDQTDEFIXSE
                    FROM
                      RECESERV
                    WHERE
                      (CDPRATO       = :CDPRATO)    AND
                      (CDFILAUXPRAT  = :CDFILAUX)   AND
                      (CDFILIAL      = :CDFILIORIG) AND
                      (CDSERVFILI    = :CDSERVORIG) AND
                      (:IDTIPORECE   = 'S')         AND
                      (CDPRODUTO NOT IN ( SELECT CDPRODUTO
                                          FROM RECESERV
                                          WHERE
                                            CDPRATO      = :CDPRATO  AND
                                            CDFILAUXPRAT = :CDFILAUX AND
                                            CDFILIAL     = :CDFILIDEST   AND
                                            CDSERVFILI   = :CDSERVDEST )))";

        $param = array(
            "CDFILIDEST"   => $cdfilidest,
            "PROPORCAO"    => $proporcao,
            "CDPRATO"      => $cdprato,
            "CDFILAUX"     => $cdfilauxprat,
            "IDTIPORECE"   => $receitaorig,
            "CDFILCENTPME" => $cdfilcentpme,
            "CDTIPOCARD"   => $cdtipocard,
            "CDFILIORIG"   => $cdfiliorig,
            "CDSERVORIG"   => $cdservorig,
            "CDSERVDEST"   => $cdservdest,
            "NRORG"        => $nrorg
        );

        try {
            $conn = \Setforms2\Runtime\Connection::getInstance();
            $conn->execute($query, $param);
            return true;
        } catch (\Exception $e) {
            throw $e;
        }
    }
}