var ReportBugController = function(templateManager, eventAggregator, metaDataFactory, ZHPromise, ScreenService, ReportBugService){
    var reportBugWidget;
    var reportBugWidgetName = 'reportBugWidget';

    function getVersionData(){
        var promise = templateManager.versionData ? ZHPromise.when() : templateManager.updateVersionData();
        return promise.then(function(){
            return Util.clone(templateManager.versionData);
        });
    }

    function getLastActiveWidgetName(){
        var lastActiveWidgetName;
        var activeWidget = templateManager.container.getActiveWidget();
        if(activeWidget.name != reportBugWidgetName){
            lastActiveWidgetName = activeWidget.name;
        } else {
            lastActiveWidgetName = activeWidget.lastActiveWidget ? activeWidget.lastActiveWidget.name : '';
        }
        return lastActiveWidgetName;
    }

    function buildRowToSend(currentRow, versionData){
        var navigator = window.navigator;
        delete versionData.dependencies.current;
        delete currentRow.$error;
        currentRow.containerName = templateManager.container.name || '';
        currentRow.widgetName = getLastActiveWidgetName();
        currentRow.versionData = versionData;
        currentRow.url = window.location.href;
        currentRow.navigator = {
            name: navigator.appName,
            vendor: navigator.vendor,
            version: navigator.appVersion
        };
        return currentRow;
    }

    function sendEmail(widget){
        if(widget.isValid()){
            getVersionData()
                .then(function(versionData){
                    var currentRow = buildRowToSend(widget.currentRow, versionData);
                    ReportBugService.sendEmail(currentRow).then(function(){
                        ScreenService.successNotification('Bug Reported!');
                        ScreenService.closePopup();
                    });
                })
                .catch(function(e){
                    ScreenService.errorNotification('Error!');
                    ScreenService.closePopup();
                });
        }
    }

    function getWidgetActions(){
        var cancelAction = {
            name: 'CANCEL',
            label: 'Cancel',
            showAsAction: 'back',
            events: [
                {
                    name: 'ActionEvent',
                    code: 'ScreenService.closePopup();'
                }
            ]
        };
        var sendAction = {
            name: 'SEND',
            label: 'Send E-mail',
            showAsAction: 'never',
            events: [
                {
                    name: 'ActionEvent',
                    code: 'args.owner.widget.sendEmail(args.owner.widget)'
                }
            ]
        };
        return [cancelAction, sendAction];
    }

    function getWidgetFields(){
        var emailField = {
            name: 'EMAIL',
            label: 'E-mail',
            template: 'field/text-edit.html',
            defaultValue: templateManager.project.reportBugDefaultEmail,
            isVisible: true,
            readOnly: true,
            validations: {
                required: true
            }
        };
        var ccField = {
            name: 'CC',
            label: 'Cc',
            template: 'field/text-edit.html',
            help: 'Use ";" to insert multiple emails',
            isVisible: true
        };
        var typeField = {
            name: 'TYPE',
            label: 'Type',
            template: 'field/select-native.html',
            isVisible: true,
            translate: true,
            defaultValue: 'B',
            valueField: 'value',
            descriptionField: 'description',
            validations: {
                required: true
            },
            dataSource: {
                name: 'issueType',
                data: [
                    {
                        value: 'B',
                        description: 'Bug'
                    },
                    {
                        value: 'I',
                        description: 'Improvement'
                    }
                ]
            }
        };
        var descriptionField = {
            name: 'DESCRIPTION',
            label: 'Description',
            template: 'field/textarea.html',
            isVisible: true,
            validations: {
                required: true
            }
        };
        return [emailField, ccField, typeField, descriptionField];
    }

    function buildReportBugWidget(){
        if(!reportBugWidget){
            var widget = {
                isZhuAclElement: true,
                name: reportBugWidgetName,
                label: 'Report Bug',
                template: 'widget/form.html',
                formTemplate: 'widget/form.html',
                showDescriptionOrder: false,
                showAsModal: true,
                isVisible: true,
                events: [
                    {
                        name: 'WidgetOnEnter',
                        code: 'args.owner.newRow()'
                    }
                ],
                actions: getWidgetActions(),
                fields: getWidgetFields()
            };
            reportBugWidget = metaDataFactory.widgetFactory(widget, templateManager.container);
            reportBugWidget.sendEmail = sendEmail;
        }
        return reportBugWidget;
    }

    eventAggregator.subscribe('OpenReportBug', function(){
        buildReportBugWidget();
        ScreenService.toggleSideMenu();
        ScreenService.openPopup(reportBugWidget);
    });
};

ZeedhiController.controller('ReportBugController', ReportBugController);